@@ -6,7 +6,7 @@ import (
 	"github.com/logrusorgru/aurora"
 
 	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/pkg/iostreams"
+	"github.com/superfly/flyctl/iostreams"
 )
 
 func PrintServicesList(s *iostreams.IOStreams, services []api.Service) {
